/*******************************************************************************
* File Name: SW_INP.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SW_INP.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 SW_INP__PORT == 15 && ((SW_INP__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: SW_INP_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void SW_INP_Write(uint8 value) 
{
    uint8 staticBits = (SW_INP_DR & (uint8)(~SW_INP_MASK));
    SW_INP_DR = staticBits | ((uint8)(value << SW_INP_SHIFT) & SW_INP_MASK);
}


/*******************************************************************************
* Function Name: SW_INP_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  SW_INP_DM_STRONG     Strong Drive 
*  SW_INP_DM_OD_HI      Open Drain, Drives High 
*  SW_INP_DM_OD_LO      Open Drain, Drives Low 
*  SW_INP_DM_RES_UP     Resistive Pull Up 
*  SW_INP_DM_RES_DWN    Resistive Pull Down 
*  SW_INP_DM_RES_UPDWN  Resistive Pull Up/Down 
*  SW_INP_DM_DIG_HIZ    High Impedance Digital 
*  SW_INP_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void SW_INP_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SW_INP_0, mode);
}


/*******************************************************************************
* Function Name: SW_INP_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SW_INP_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SW_INP_Read(void) 
{
    return (SW_INP_PS & SW_INP_MASK) >> SW_INP_SHIFT;
}


/*******************************************************************************
* Function Name: SW_INP_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SW_INP_ReadDataReg(void) 
{
    return (SW_INP_DR & SW_INP_MASK) >> SW_INP_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SW_INP_INTSTAT) 

    /*******************************************************************************
    * Function Name: SW_INP_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SW_INP_ClearInterrupt(void) 
    {
        return (SW_INP_INTSTAT & SW_INP_MASK) >> SW_INP_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
